@@ -22,18 +22,20 @@ class AIHClient:
             raise AIHE.AIHClientException('AIHClient has not been initialized yet.')
         
     
-    def __init__(self, environment:str, client_id:str, client_secret:str):
+    def __init__(self, environment:str, client_id:str, client_secret:str, location:str):
         """
         IN: environment (str)   - Defines where the client should connect to.
             client_id (str)     - The id the client should connect with. 
             client_secret (str) - The secret the client should connect with.
+            location (str)      - The location where the service is running (we, ne, ea, etc.)
         """
         AIHClient._instance = self
         
         self.client_id = client_id
         self.client_secret = client_secret
         self.environment = environment
-        self.token_url = f'https://{self.environment}-idsvr-we-api.azurewebsites.net/connect/token'
+        self.location = location
+        self.token_url = f'https://{self.environment}-idsvr-{self.location}-api.azurewebsites.net/connect/token'
         
         # Creates the client
         backend = BackendApplicationClient(client_id=self.client_id)
@@ -82,10 +84,11 @@ class AIHClient:
             self._update_token()
         
         if parameters:
+            print(parameters)
             params = '&'.join([f'{k}={v}' for k,v in parameters])
-            url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}?{params}'   
+            url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}?{params}'   
         else:
-            url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}'
+            url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}'
         
         response = self.client.get(url)
                 
@@ -113,7 +116,7 @@ class AIHClient:
         if(self._is_expired()):
             self._update_token()
         
-        url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
+        url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}' 
         headers = {"Content-Type": "application/json"}
         response = self.client.put(url=url, data=json.dumps(data), headers=headers)
         
@@ -121,7 +124,7 @@ class AIHClient:
             if 'unauthorized' in response.text.lower():
                 # If unauthorized, try to get new toke and try once more
                 self._update_token()
-                url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
+                url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}' 
                 headers = {"Content-Type": "application/json"}
                 response = self.client.put(url=url, data=json.dumps(data), headers=headers)
 
@@ -146,7 +149,7 @@ class AIHClient:
         if(self._is_expired()):
             self._update_token()
         
-        url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
+        url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}' 
         headers = {"Content-Type": "application/json"}
         response = self.client.post(url=url, data=json.dumps(data), headers=headers)
         
@@ -154,7 +157,7 @@ class AIHClient:
             if 'unauthorized' in response.text.lower():
                 # If unauthorized, try to get new toke and try once more
                 self._update_token()
-                url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}' 
+                url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}' 
                 headers = {"Content-Type": "application/json"}
                 response = self.client.post(url=url, data=json.dumps(data), headers=headers)
 
@@ -169,7 +172,7 @@ class AIHClient:
             raise AIHE.AIHClientException(f'Cannot interpret response as JSON. API might be wrong.\nAPI was: {url}\n\nResponse was:\n{response.text}')
             
             
-    def _delete(self, api:str, endpoint:str, id:str):
+    def _delete(self, api:str, endpoint:str, id:str=None):
         """
         Sends a HTTPS DELETE request for the given endpoint.
         Raises an error if HTTPS error occurs.
@@ -177,18 +180,19 @@ class AIHClient:
         IN: api (str)      - Defines which API to use
             endpoint (str) - Defines the endpoint send a GET request to.
         """
-        
         if(self._is_expired()):
             self._update_token()
-        
-        url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}/{id}'        
+        if id == None: 
+            url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}'
+        else: 
+            url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}/{id}'        
         response = self.client.delete(url)
         
         if response.status_code < 200 or response.status_code >= 300:
             if 'unauthorized' in response.text.lower():
                 # If unauthorized, try to get new toke and try once more
                 self._update_token()
-                url = f'https://{self.environment}-{api}-we-api.azurewebsites.net/{endpoint}/{id}'        
+                url = f'https://{self.environment}-{api}-{self.location}-api.azurewebsites.net/{endpoint}/{id}'        
                 response = self.client.delete(url)
 
                 if response.status_code < 200 or response.status_code >= 300:
@@ -209,7 +213,7 @@ class AIHClient:
         if(self._is_expired()):
             self._update_token()
         
-        url = f'https://{self.environment}-du-we-api.azurewebsites.net/files/{file_id}/Data'
+        url = f'https://{self.environment}-du-{self.location}-api.azurewebsites.net/files/{file_id}/Data'
         response = self.client.get(url)
 
         return response.content
@@ -233,7 +237,7 @@ class AIHClient:
         user = User().get(parameters=[('keyword', self.client_id)])
 
         fileextension = name.split('.')[-1]
-        url = f'https://{self.environment}-du-we-api.azurewebsites.net/Files'
+        url = f'https://{self.environment}-du-{self.location}-api.azurewebsites.net/Files'
         files = {
             'Id' : (None, ''),
             'DataTypeId' : (None, datatype_id),
@@ -257,11 +261,26 @@ class AIHClient:
         if(self._is_expired()):
             self._update_token()
         
-        url = f'https://{self.environment}-aih-we-api.azurewebsites.net/api/v1/multimedia/{container}/{name}'        
+        url = f'https://{self.environment}-aih-{self.location}-api.azurewebsites.net/api/v1/multimedia/{container}/{name}'        
         response = self.client.get(url)
                 
         return response.content
 
+    def _download_maintenance_media(self, id:str):
+            """
+            To get download a file from the media objects.
+            IN: id (str) - To specify the id of the file to download
+                
+            OUT: the content of the downloaded file
+            """
+            if(self._is_expired()):
+                self._update_token()
+            
+            url = f'https://{self.environment}-quality-{self.location}-api.azurewebsites.net/Medias/{id}/Data'
+
+            response = self.client.get(url)
+                    
+            return response.content
 
     def _upload_media(self, container, file, name):
         """
@@ -278,13 +297,36 @@ class AIHClient:
             self._update_token()
         
         
-        url = f'https://{self.environment}-aih-we-api.azurewebsites.net/api/v1/media'
+        url = f'https://{self.environment}-aih-{self.location}-api.azurewebsites.net/api/v1/media'
         
         files = {'file' : (name, file)}
         
         response = self.client.post(url=url, files=files)
         
         return response.json()
+
+    def _upload_maintenance_media(self, file, name, fileType):
+        """
+        upload_file uploads a file to a data type.
+
+        IN: datatype_id (str) - The id of the DataType to uplaod the file to.
+            file (bytes)      - The bytes for the file to upload.
+            name (str)        - The name the file should be stored as. The name must include the file extension.
+
+        OUT: (json) - The json response
+        """
         
+        if(self._is_expired()):
+            self._update_token()
+        
+        
+        url = f'https://{self.environment}-quality-{self.location}-api.azurewebsites.net/Medias'
+        
+        files = {'File' : (name, file)}
+        fileType = {'Type': fileType}
+        
+        response = self.client.post(url=url, files=files, data=fileType)
+        
+        return response.json()     
 
 from AIH_SDK.Identity import User
\ No newline at end of file
